@@ -27,10 +27,10 @@ import (
 	templateinformers "github.com/openshift/client-go/template/informers/externalversions"
 
 	sampopapi "github.com/openshift/api/samples/v1"
-	sampcache "github.com/openshift/cluster-samples-operator/pkg/cache"
-	sampopclient "github.com/openshift/cluster-samples-operator/pkg/client"
 	sampleclientv1 "github.com/openshift/client-go/samples/clientset/versioned"
 	sampopinformers "github.com/openshift/client-go/samples/informers/externalversions"
+	sampcache "github.com/openshift/cluster-samples-operator/pkg/cache"
+	sampopclient "github.com/openshift/cluster-samples-operator/pkg/client"
 
 	operatorstatus "github.com/openshift/cluster-samples-operator/pkg/operatorstatus"
 	"github.com/openshift/cluster-samples-operator/pkg/stub"
@@ -46,19 +46,18 @@ type Controller struct {
 	restconfig *restclient.Config
 	cvowrapper *operatorstatus.ClusterOperatorHandler
 
-	crWorkqueue    workqueue.RateLimitingInterface
-	osSecWorkqueue workqueue.RateLimitingInterface
+	crWorkqueue workqueue.RateLimitingInterface
+	isWorkqueue workqueue.RateLimitingInterface
+	tWorkqueue  workqueue.RateLimitingInterface
+
 	ocSecWorkqueue workqueue.RateLimitingInterface
-	isWorkqueue    workqueue.RateLimitingInterface
-	tWorkqueue     workqueue.RateLimitingInterface
 
-	crInformer    cache.SharedIndexInformer
-	osSecInformer cache.SharedIndexInformer
+	crInformer cache.SharedIndexInformer
+	isInformer cache.SharedIndexInformer
+	tInformer  cache.SharedIndexInformer
+
 	ocSecInformer cache.SharedIndexInformer
-	isInformer    cache.SharedIndexInformer
-	tInformer     cache.SharedIndexInformer
 
-	kubeOSNSInformerFactory kubeinformers.SharedInformerFactory
 	kubeOCNSInformerFactory kubeinformers.SharedInformerFactory
 	imageInformerFactory    imageinformers.SharedInformerFactory
 	templateInformerFactory templateinformers.SharedInformerFactory
@@ -84,10 +83,9 @@ func NewController() (*Controller, error) {
 		restconfig:     kubeconfig,
 		cvowrapper:     operatorstatus.NewClusterOperatorHandler(operatorClient),
 		crWorkqueue:    workqueue.NewNamedRateLimitingQueue(workqueue.DefaultControllerRateLimiter(), "samplesconfig-changes"),
-		osSecWorkqueue: workqueue.NewNamedRateLimitingQueue(workqueue.DefaultControllerRateLimiter(), "openshift-secret-changes"),
-		ocSecWorkqueue: workqueue.NewNamedRateLimitingQueue(workqueue.DefaultControllerRateLimiter(), "openshift-config-namespace-secret-changes"),
 		isWorkqueue:    workqueue.NewNamedRateLimitingQueue(workqueue.DefaultControllerRateLimiter(), "imagestream-changes"),
 		tWorkqueue:     workqueue.NewNamedRateLimitingQueue(workqueue.DefaultControllerRateLimiter(), "template-changes"),
+		ocSecWorkqueue: workqueue.NewNamedRateLimitingQueue(workqueue.DefaultControllerRateLimiter(), "openshift-config-namespace-secret-changes"),
 		listers:        listers,
 	}
 
@@ -114,7 +112,6 @@ func NewController() (*Controller, error) {
 		return nil, err
 	}
 
-	c.kubeOSNSInformerFactory = kubeinformers.NewFilteredSharedInformerFactory(kubeClient, defaultResyncDuration, "openshift", nil)
 	c.kubeOCNSInformerFactory = kubeinformers.NewFilteredSharedInformerFactory(kubeClient, defaultResyncDuration, "openshift-config", nil)
 	//TODO - eventually a k8s go-client deps bump will lead to the form below, similar to the image registry operator's kubeinformer initialization,
 	// and similar to what is available with the openshift go-client for imagestreams and templates
@@ -123,12 +120,16 @@ func NewController() (*Controller, error) {
 	c.templateInformerFactory = templateinformers.NewSharedInformerFactoryWithOptions(templateClient, defaultResyncDuration, templateinformers.WithNamespace("openshift"))
 	c.sampopInformerFactory = sampopinformers.NewSharedInformerFactory(sampopClient, defaultResyncDuration)
 
-	c.osSecInformer = c.kubeOSNSInformerFactory.Core().V1().Secrets().Informer()
-	c.osSecInformer.AddEventHandler(c.osSecretInformerEventHandler())
-	c.listers.OpenShiftNamespaceSecrets = c.kubeOSNSInformerFactory.Core().V1().Secrets().Lister().Secrets("openshift")
-
+	// A note on the fact we are listening on secrets in the openshift-config namespace, even though we no longer
+	// copy that secret to the openshift namespace for imagestream import
+	// 1) we still inspect that secret to make sure it has credentials for registry.redhat.io, unless the samples
+	// registry is overriden.  If those credentials don't exist, the imagestream imports will fail.  We capture these
+	// results in prometheus metrics/alerts.
+	// 2) we employ the lister/sharedinformer/workqueue controller apparatus to get cached versions of the data, so
+	// we do not have to hit the API server everytime somebody queries our prometheus stuff
+	// 3) however, you have to go all the way with this, including to workqueue, to get the underlying watches so the
+	// cache is at least initially populated
 	c.ocSecInformer = c.kubeOCNSInformerFactory.Core().V1().Secrets().Informer()
-	c.ocSecInformer.AddEventHandler(c.ocSecretInformerEventHandler())
 	c.listers.ConfigNamespaceSecrets = c.kubeOCNSInformerFactory.Core().V1().Secrets().Lister().Secrets("openshift-config")
 
 	c.isInformer = c.imageInformerFactory.Image().V1().ImageStreams().Informer()
@@ -154,20 +155,17 @@ func NewController() (*Controller, error) {
 
 func (c *Controller) Run(stopCh <-chan struct{}) error {
 	defer c.crWorkqueue.ShutDown()
-	defer c.osSecWorkqueue.ShutDown()
-	defer c.ocSecWorkqueue.ShutDown()
 	defer c.isWorkqueue.ShutDown()
 	defer c.tWorkqueue.ShutDown()
+	defer c.ocSecWorkqueue.ShutDown()
 
-	c.kubeOSNSInformerFactory.Start(stopCh)
-	c.kubeOCNSInformerFactory.Start(stopCh)
 	c.imageInformerFactory.Start(stopCh)
 	c.templateInformerFactory.Start(stopCh)
 	c.sampopInformerFactory.Start(stopCh)
+	c.kubeOCNSInformerFactory.Start(stopCh)
 
 	logrus.Println("waiting for informer caches to sync")
-	if !cache.WaitForCacheSync(stopCh, c.osSecInformer.HasSynced, c.ocSecInformer.HasSynced,
-		c.isInformer.HasSynced, c.tInformer.HasSynced, c.crInformer.HasSynced) {
+	if !cache.WaitForCacheSync(stopCh, c.isInformer.HasSynced, c.tInformer.HasSynced, c.crInformer.HasSynced, c.ocSecInformer.HasSynced) {
 		return fmt.Errorf("failed to wait for caches to sync")
 	}
 
@@ -177,18 +175,6 @@ func (c *Controller) Run(stopCh <-chan struct{}) error {
 		getter:    &crGetter{},
 	}
 	go wait.Until(crQueueWorker.workqueueProcessor, time.Second, stopCh)
-	osSecQueueWorker := queueWorker{
-		c:         c,
-		workQueue: c.osSecWorkqueue,
-		getter:    &osSecretGetter{},
-	}
-	go wait.Until(osSecQueueWorker.workqueueProcessor, time.Second, stopCh)
-	ocSecQueueWorker := queueWorker{
-		c:         c,
-		workQueue: c.ocSecWorkqueue,
-		getter:    &ocSecretGetter{},
-	}
-	go wait.Until(ocSecQueueWorker.workqueueProcessor, time.Second, stopCh)
 	isQueueWorker := queueWorker{
 		c:         c,
 		workQueue: c.isWorkqueue,
@@ -205,6 +191,12 @@ func (c *Controller) Run(stopCh <-chan struct{}) error {
 	for i := 0; i < 5; i++ {
 		go wait.Until(tQueueWorker.workqueueProcessor, time.Second, stopCh)
 	}
+	ocSecQueueWorker := queueWorker{
+		c:         c,
+		workQueue: c.ocSecWorkqueue,
+		getter:    &ocSecretGetter{},
+	}
+	go wait.Until(ocSecQueueWorker.workqueueProcessor, time.Second, stopCh)
 
 	logrus.Println("started events processor")
 	<-stopCh
@@ -225,12 +217,6 @@ func (g *crGetter) Get(c *Controller, key string) (runtime.Object, error) {
 	return c.listers.Config.Get(sampopapi.ConfigName)
 }
 
-type osSecretGetter struct{}
-
-func (g *osSecretGetter) Get(c *Controller, key string) (runtime.Object, error) {
-	return c.listers.OpenShiftNamespaceSecrets.Get(key)
-}
-
 type ocSecretGetter struct{}
 
 func (g *ocSecretGetter) Get(c *Controller, key string) (runtime.Object, error) {
@@ -416,10 +402,6 @@ func (c *Controller) crInformerEventHandler() cache.ResourceEventHandlerFuncs {
 	return c.commonInformerEventHandler(&crQueueKeyGen{}, c.crWorkqueue)
 }
 
-func (c *Controller) osSecretInformerEventHandler() cache.ResourceEventHandlerFuncs {
-	return c.commonInformerEventHandler(&secretQueueKeyGen{}, c.osSecWorkqueue)
-}
-
 func (c *Controller) ocSecretInformerEventHandler() cache.ResourceEventHandlerFuncs {
 	return c.commonInformerEventHandler(&secretQueueKeyGen{}, c.ocSecWorkqueue)
 }
